@@ -18,17 +18,22 @@ const int VM_PLATFORM = 2;
 enum Category {
   /// Indicates that a library can be used in a browser context.
   client,
+
   /// Indicates that a library can be used in a command line context.
   server,
+
   /// Indicates that a library can be used from embedded devices.
   embedded
 }
 
 Category parseCategory(String name) {
   switch (name) {
-    case "Client": return Category.client;
-    case "Server": return Category.server;
-    case "Embedded": return Category.embedded;
+    case "Client":
+      return Category.client;
+    case "Server":
+      return Category.server;
+    case "Embedded":
+      return Category.embedded;
   }
   return null;
 }
@@ -36,212 +41,153 @@ Category parseCategory(String name) {
 /// Mapping of "dart:" library name (e.g. "core") to information about that
 /// library.
 const Map<String, LibraryInfo> libraries = const {
-  "async": const LibraryInfo(
-      "async/async.dart",
+  "async": const LibraryInfo("async/async.dart",
       categories: "Client,Server",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/async_patch.dart"),
-
-  "_blink": const LibraryInfo(
-      "_blink/dartium/_blink_dartium.dart",
-      categories: "Client",
-      implementation: true,
-      documented: false,
-      platforms: VM_PLATFORM),
-
-  "_chrome": const LibraryInfo(
-      "_chrome/dart2js/chrome_dart2js.dart",
-      categories: "Client",
-      documented: false),
-
-  "collection": const LibraryInfo(
-      "collection/collection.dart",
+  "_chrome": const LibraryInfo("_chrome/dart2js/chrome_dart2js.dart",
+      categories: "Client", documented: false),
+  "collection": const LibraryInfo("collection/collection.dart",
       categories: "Client,Server,Embedded",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/collection_patch.dart"),
-
-  "convert": const LibraryInfo(
-      "convert/convert.dart",
+  "convert": const LibraryInfo("convert/convert.dart",
       categories: "Client,Server",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/convert_patch.dart"),
-
-  "core": const LibraryInfo(
-      "core/core.dart",
+  "core": const LibraryInfo("core/core.dart",
       categories: "Client,Server,Embedded",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/core_patch.dart"),
-
-  "developer": const LibraryInfo(
-      "developer/developer.dart",
+  "developer": const LibraryInfo("developer/developer.dart",
       categories: "Client,Server,Embedded",
       maturity: Maturity.UNSTABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/developer_patch.dart"),
-
-  "html": const LibraryInfo(
-      "html/dartium/html_dartium.dart",
+  "ffi": const LibraryInfo("ffi/ffi.dart",
+      categories: "Server",
+      // TODO(dacoharkes): Update maturity when we release dart:ffi.
+      // https://github.com/dart-lang/sdk/issues/34452
+      maturity: Maturity.EXPERIMENTAL),
+  "html": const LibraryInfo("html/dart2js/html_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "html/dart2js/html_dart2js.dart"),
-
-  "html_common": const LibraryInfo(
-      "html/html_common/html_common.dart",
+      platforms: DART2JS_PLATFORM),
+  "html_common": const LibraryInfo("html/html_common/html_common.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
       dart2jsPath: "html/html_common/html_common_dart2js.dart",
       documented: false,
       implementation: true),
-
-  "indexed_db": const LibraryInfo(
-      "indexed_db/dartium/indexed_db_dartium.dart",
+  "indexed_db": const LibraryInfo("indexed_db/dart2js/indexed_db_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "indexed_db/dart2js/indexed_db_dart2js.dart"),
-
-  "io": const LibraryInfo(
-      "io/io.dart",
+      platforms: DART2JS_PLATFORM),
+  "_http":
+      const LibraryInfo("_http/http.dart", categories: "", documented: false),
+  "io": const LibraryInfo("io/io.dart",
       categories: "Server",
       dart2jsPatchPath: "_internal/js_runtime/lib/io_patch.dart"),
-
-  "isolate": const LibraryInfo(
-      "isolate/isolate.dart",
+  "isolate": const LibraryInfo("isolate/isolate.dart",
       categories: "Client,Server",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/isolate_patch.dart"),
-
-  "js": const LibraryInfo(
-      "js/dartium/js_dartium.dart",
+  "js": const LibraryInfo("js/dart2js/js_dart2js.dart",
       categories: "Client",
       maturity: Maturity.STABLE,
-      dart2jsPath: "js/dart2js/js_dart2js.dart"),
-
-  "js_util": const LibraryInfo(
-      "js_util/dartium/js_util_dartium.dart",
+      platforms: DART2JS_PLATFORM),
+  "_js": const LibraryInfo("js/_js.dart",
+      categories: "Client",
+      dart2jsPatchPath: "js/_js_client.dart",
+      documented: false,
+      platforms: DART2JS_PLATFORM),
+  "js_util": const LibraryInfo("js_util/dart2js/js_util_dart2js.dart",
       categories: "Client",
       maturity: Maturity.STABLE,
-      dart2jsPath: "js_util/dart2js/js_util_dart2js.dart"),
-
-  "math": const LibraryInfo(
-      "math/math.dart",
+      platforms: DART2JS_PLATFORM),
+  "math": const LibraryInfo("math/math.dart",
       categories: "Client,Server,Embedded",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/math_patch.dart"),
-
-  "mirrors": const LibraryInfo(
-      "mirrors/mirrors.dart",
+  "mirrors": const LibraryInfo("mirrors/mirrors.dart",
       categories: "Client,Server",
       maturity: Maturity.UNSTABLE,
-      dart2jsPatchPath: "_internal/js_runtime/lib/mirrors_patch.dart"),
-
-  "nativewrappers": const LibraryInfo(
-      "html/dartium/nativewrappers.dart",
+      dart2jsPatchPath: "_internal/js_runtime/lib/mirrors_patch_cfe.dart"),
+  "nativewrappers": const LibraryInfo("html/dartium/nativewrappers.dart",
       categories: "Client",
       implementation: true,
       documented: false,
       platforms: VM_PLATFORM),
-
-  "typed_data": const LibraryInfo(
-      "typed_data/typed_data.dart",
+  "typed_data": const LibraryInfo("typed_data/typed_data.dart",
       categories: "Client,Server,Embedded",
       maturity: Maturity.STABLE,
       dart2jsPatchPath: "_internal/js_runtime/lib/typed_data_patch.dart"),
-
   "_native_typed_data": const LibraryInfo(
       "_internal/js_runtime/lib/native_typed_data.dart",
       categories: "",
       implementation: true,
       documented: false,
       platforms: DART2JS_PLATFORM),
-
-  "svg": const LibraryInfo(
-      "svg/dartium/svg_dartium.dart",
+  "cli": const LibraryInfo("cli/cli.dart",
+      categories: "Server",
+      dart2jsPatchPath: "_internal/js_runtime/lib/cli_patch.dart"),
+  "svg": const LibraryInfo("svg/dart2js/svg_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "svg/dart2js/svg_dart2js.dart"),
-
-  "web_audio": const LibraryInfo(
-      "web_audio/dartium/web_audio_dartium.dart",
+      platforms: DART2JS_PLATFORM),
+  "web_audio": const LibraryInfo("web_audio/dart2js/web_audio_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "web_audio/dart2js/web_audio_dart2js.dart"),
-
-  "web_gl": const LibraryInfo(
-      "web_gl/dartium/web_gl_dartium.dart",
+      platforms: DART2JS_PLATFORM),
+  "web_gl": const LibraryInfo("web_gl/dart2js/web_gl_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "web_gl/dart2js/web_gl_dart2js.dart"),
-
-  "web_sql": const LibraryInfo(
-      "web_sql/dartium/web_sql_dartium.dart",
+      platforms: DART2JS_PLATFORM),
+  "web_sql": const LibraryInfo("web_sql/dart2js/web_sql_dart2js.dart",
       categories: "Client",
       maturity: Maturity.WEB_STABLE,
-      dart2jsPath: "web_sql/dart2js/web_sql_dart2js.dart"),
-
-  "_internal": const LibraryInfo(
-      "internal/internal.dart",
+      platforms: DART2JS_PLATFORM),
+  "_internal": const LibraryInfo("internal/internal.dart",
       categories: "",
       documented: false,
       dart2jsPatchPath: "_internal/js_runtime/lib/internal_patch.dart"),
-
-  "_js_helper": const LibraryInfo(
-      "_internal/js_runtime/lib/js_helper.dart",
-      categories: "",
-      documented: false,
-      platforms: DART2JS_PLATFORM),
-
+  "_js_helper": const LibraryInfo("_internal/js_runtime/lib/js_helper.dart",
+      categories: "", documented: false, platforms: DART2JS_PLATFORM),
+  "_rti": const LibraryInfo("_internal/js_runtime/lib/rti.dart",
+      categories: "", documented: false, platforms: DART2JS_PLATFORM),
   "_interceptors": const LibraryInfo(
       "_internal/js_runtime/lib/interceptors.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
-
   "_foreign_helper": const LibraryInfo(
       "_internal/js_runtime/lib/foreign_helper.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
-
-  "_isolate_helper": const LibraryInfo(
-      "_internal/js_runtime/lib/isolate_helper.dart",
-      categories: "",
-      documented: false,
-      platforms: DART2JS_PLATFORM),
-
-  "_js_mirrors": const LibraryInfo(
-      "_internal/js_runtime/lib/js_mirrors.dart",
-      categories: "",
-      documented: false,
-      platforms: DART2JS_PLATFORM),
-
-  "_js_names": const LibraryInfo(
-      "_internal/js_runtime/lib/js_names.dart",
-      categories: "",
-      documented: false,
-      platforms: DART2JS_PLATFORM),
-
+  "_js_names": const LibraryInfo("_internal/js_runtime/lib/js_names.dart",
+      categories: "", documented: false, platforms: DART2JS_PLATFORM),
   "_js_primitives": const LibraryInfo(
       "_internal/js_runtime/lib/js_primitives.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
-
   "_js_embedded_names": const LibraryInfo(
       "_internal/js_runtime/lib/shared/embedded_names.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
-
   "_async_await_error_codes": const LibraryInfo(
       "_internal/js_runtime/lib/shared/async_await_error_codes.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
-
-  "_metadata": const LibraryInfo(
-      "html/html_common/metadata.dart",
+  "_recipe_syntax": const LibraryInfo(
+      "_internal/js_runtime/lib/shared/recipe_syntax.dart",
       categories: "",
       documented: false,
       platforms: DART2JS_PLATFORM),
+  "_metadata": const LibraryInfo("html/html_common/metadata.dart",
+      categories: "", documented: false, platforms: DART2JS_PLATFORM),
 };
 
 /**
@@ -298,14 +244,14 @@ class LibraryInfo {
    */
   final Maturity maturity;
 
-  const LibraryInfo(this.path, {
-                    String categories: "",
-                    this.dart2jsPath,
-                    this.dart2jsPatchPath,
-                    this.implementation: false,
-                    this.documented: true,
-                    this.maturity: Maturity.UNSPECIFIED,
-                    this.platforms: DART2JS_PLATFORM | VM_PLATFORM})
+  const LibraryInfo(this.path,
+      {String categories: "",
+      this.dart2jsPath,
+      this.dart2jsPatchPath,
+      this.implementation: false,
+      this.documented: true,
+      this.maturity: Maturity.UNSPECIFIED,
+      this.platforms: DART2JS_PLATFORM | VM_PLATFORM})
       : _categories = categories;
 
   bool get isDart2jsLibrary => (platforms & DART2JS_PLATFORM) != 0;
@@ -348,22 +294,30 @@ class Maturity {
   static const Maturity DEPRECATED = const Maturity(0, "Deprecated",
       "This library will be remove before next major release.");
 
-  static const Maturity EXPERIMENTAL = const Maturity(1, "Experimental",
+  static const Maturity EXPERIMENTAL = const Maturity(
+      1,
+      "Experimental",
       "This library is experimental and will likely change or be removed\n"
-      "in future versions.");
+          "in future versions.");
 
-  static const Maturity UNSTABLE = const Maturity(2, "Unstable",
+  static const Maturity UNSTABLE = const Maturity(
+      2,
+      "Unstable",
       "This library is in still changing and have not yet endured\n"
-      "sufficient real-world testing.\n"
-      "Backwards-compatibility is NOT guaranteed.");
+          "sufficient real-world testing.\n"
+          "Backwards-compatibility is NOT guaranteed.");
 
-  static const Maturity WEB_STABLE = const Maturity(3, "Web Stable",
+  static const Maturity WEB_STABLE = const Maturity(
+      3,
+      "Web Stable",
       "This library is tracking the DOM evolution as defined by WC3.\n"
-      "Backwards-compatibility is NOT guaranteed.");
+          "Backwards-compatibility is NOT guaranteed.");
 
-  static const Maturity STABLE = const Maturity(4, "Stable",
+  static const Maturity STABLE = const Maturity(
+      4,
+      "Stable",
       "The library is stable. API backwards-compatibility is guaranteed.\n"
-      "However implementation details might change.");
+          "However implementation details might change.");
 
   static const Maturity LOCKED = const Maturity(5, "Locked",
       "This library will not change except when serious bugs are encountered.");
